@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERIMPORTERTEST_H
-#define FILTERIMPORTERTEST_H
+#pragma once
 
 #include <MailImporter/FilterImporterBase>
 #include <QVector>
@@ -33,5 +32,3 @@ public:
 private:
     QVector<FilterImporterData> mFilterImporterDataList;
 };
-
-#endif // FILTERIMPORTERTEST_H
